@@ -38,15 +38,13 @@
 (define c99-def-help
   '(("__builtin"
      "__builtin_va_list=void*"
-     "__attribute=__attribute__"
-     "__has_include=__has_include__"
      "__inline__=inline" "__inline=__inline__"
      "__restrict__=restrict" "__restrict=__restrict__"
      "__signed__=signed" "__signed=__signed__"
+     "asm(X)=__asm__(X)" "__asm(X)=__asm__(X)"
+     "__attribute(X)=__attribute__(X)"
      "__volatile__=volatile" "__volatile=__volatile__"
-     ;;"__THROW="
-     "asm=__asm__" "__asm=__asm__"
-     "__extension__=" "__extension=__extension__"
+     "__extension__(X)=" "__extension(X)=__extension__(X)"
      )))
 
 ;; include-helper for C99 std
